package io.tesla.webserver;

import java.io.File;

public class Runtime {
  /**
   * The directory in which the JVM is started. The user.dir system property is used for this value. There is no way to change
   * the value of the current working directory in Java [http://bugs.sun.com/bugdatabase/view%5Fbug.do?bug%5Fid=4045688].
   * 
   * If using the Java Service Wrapper, you must be aware of the wrapper.working.dir property which sets the location
   * of the current working directory in native code before starting the JVM. In the proviso JSW booter the current
   * working directory is set to the base directory of the runtime.
   * 
   */
  private File currentWorkingDirectory;

  /**
   * The base directory of the runtime.
   * 
   * An attempt is made in the launching mechanism to make the current working directory the same as the runtime base
   * directory. Users are encouraged to use the runtime base directory and it is the job of implementors of booters,
   * like the JSW booter, to align these values.
   */
  private File runtimeBaseDirectory;

  /**
   * The directory in which runtime configuration is stored.
   */
  private File configurationDirectory;

  /**
   * The directory where applications store their output. Typically this is kept outside the runtime base directory so
   * that upgrades are easier to perform.
   */
  private File workDirectory;

  public Runtime() {

    this.currentWorkingDirectory = new File(System.getProperty("user.dir"));

    if (new File(currentWorkingDirectory, "pom.xml").exists()) {
      //
      // In Situ with a Maven project
      //
      this.runtimeBaseDirectory = new File(currentWorkingDirectory, "target/runtime");
      this.workDirectory = new File(currentWorkingDirectory, "target/work");
    } else if ( new File(currentWorkingDirectory, "bin/jsw").exists()){
      //
      // JSW
      //
      this.runtimeBaseDirectory = currentWorkingDirectory;
      this.workDirectory = new File(currentWorkingDirectory, "work");
    }

    System.setProperty("runtime.home", runtimeBaseDirectory.getAbsolutePath());
    System.setProperty("workDirectory", workDirectory.getAbsolutePath());

    System.out.println("currentWorkingDirectory: " + currentWorkingDirectory);
    System.out.println("runtimeBaseDirectory: " + runtimeBaseDirectory);
    System.out.println("workDirectory: " + workDirectory);

  }

  public File getCurrentWorkingDirectory() {
    return currentWorkingDirectory;
  }
  
  public File getRuntimeBaseDirectory() {
    return runtimeBaseDirectory;
  }

  public File getWorkDirectory() {
    return workDirectory;
  }
}
