package io.tesla.webserver;

import java.net.MalformedURLException;
import java.net.URL;

import javax.net.ssl.SSLContext;
import javax.servlet.Servlet;

public interface WebServer {

  void stop() throws Exception;
  void start() throws Exception;
  void initialize() throws Exception;
  int getPort();

  URL getUrl() throws MalformedURLException;


  void enableSsl(SSLContext sslContext);

  /**
   * Add authentication handler to the given pathspec.
   * 
   * @param pathSpec e.g. "/path/*"
   * @param authName e.g. BASIC, DIGEST
   */
  void addAuthentication(String pathSpec, String authName);

  /**
   * Add the given user and password to the servers security realm. The password may be any type supported by the
   * authentication type (e.g. a certificate for client side certificate auth).
   */
  void addUser(String user, Object password);

  void addServlet(Servlet servlet, String pathSpec);
  
  void enableProxy();
}
